Permuted congruential generator (64-bit, PCG64)
===============================================

.. currentmodule:: numpy.random

.. autoclass:: PCG64
    :members: __init__
    :exclude-members: __init__

State
-----

.. autosummary::
   :toctree: generated/

   ~PCG64.state

Parallel generation
-------------------
.. autosummary::
   :toctree: generated/

   ~PCG64.advance
   ~PCG64.jumped

Extending
---------
.. autosummary::
   :toctree: generated/

   ~PCG64.cffi
   ~PCG64.ctypes
